# -*- coding: utf-8 -*-
#
# PWemulator Plugin by gutemine
#
pwe_version="0.3"
#
from Components.ActionMap import ActionMap
from Components.Label import Label
from Components.config import config, ConfigSubsection, ConfigText, ConfigBoolean, ConfigInteger, ConfigSelection, getConfigListEntry
from Components.ConfigList import ConfigListScreen
from Plugins.Plugin import PluginDescriptor
from Components.Pixmap import Pixmap
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InputBox import InputBox
from Components.Input import Input
from Screens.ChoiceBox import ChoiceBox
from Components.AVSwitch import AVSwitch
from Components.SystemInfo import SystemInfo
from Screens.Console import Console
from Components.MenuList import MenuList
from Components.Slider import Slider
from Components.Sources.Clock import Clock
from Components.Sources.StaticText import StaticText
from enigma import  ePoint, eLCD, fbClass, eRCInput, eDBoxLCD, getDesktop, quitMainloop, eConsoleAppContainer, eDVBVolumecontrol, eTimer, eActionMap
from Tools.LoadPixmap import LoadPixmap
import os 
import Components.Sensors
import Components.FanControl
from Components.FanControl import fancontrol

pwe_plugindir="/usr/lib/enigma2/python/Plugins/SystemPlugins/PWemulator"

yes_no_descriptions = {False: _("no"), True: _("yes")}

config.plugins.pwe = ConfigSubsection()
config.plugins.pwe.maxrpm = ConfigInteger(default = 1800, limits=(800,16000))
config.plugins.pwe.minrpm = ConfigInteger(default = 500, limits=(100,8000))
config.plugins.pwe.maxtemp = ConfigInteger(default = 50, limits=(20,99))
config.plugins.pwe.mintemp = ConfigInteger(default = 45, limits=(20,99))
config.plugins.pwe.idle = ConfigBoolean(default = True, descriptions=yes_no_descriptions)

def PWemulator_getSensorValue(self, sensorid):
	value = -1
	sensor = self.sensors_list[sensorid]
	if sensor[0] == self.TYPE_TEMPERATURE:
		f = open("%s/value" % sensor[3], "r")
		try:
			value = int(f.readline().strip())
#			print "[PWwmulator] sensor read"
		except:
			print "[PWwmulator] sensor glitch"
		f.close()
	elif sensor[0] == self.TYPE_FAN_RPM:
		value = fancontrol.getFanSpeed(sensor[3])
	return value

#rename on startup
Components.Sensors.Sensors.getSensorValue=PWemulator_getSensorValue

def PWemulator_getFanSpeed(self, fanid):
	value=0
	f = open("/proc/stb/fp/fan_speed", "r")
	try:
		value = int(f.readline().strip()[:-4])
#		print "[PWemulator] fan speed read"
	except:
		print "[PWemulator] fan speed glitch"
	f.close()
	return value
	
def PWemulator_getVoltage(self, fanid):
	value=0
	f = open("/proc/stb/fp/fan_vlt", "r")
	try:
		value = int(f.readline().strip(), 16)
#		print "[PWemulator] get voltage read"
	except:
		print "[PWemulator] get voltage glitch"
	f.close()
	return value
	
def PWemulator_getPWM(self, fanid):
	value=0
	f = open("/proc/stb/fp/fan_pwm", "r")
	try:
		value = int(f.readline().strip(), 16)
#		print "[PWemulator] get pwm read"
	except:
		print "[PWemulator] get pwm glitch"
	f.close()
	return value
	
#rename on startup
Components.FanControl.FanControl.getFanSpeed=PWemulator_getFanSpeed
Components.FanControl.FanControl.getVoltage=PWemulator_getVoltage
Components.FanControl.FanControl.getPWM=PWemulator_getPWM

sz_w = getDesktop(0).size().width() 

class PWemulator(Screen, ConfigListScreen):
    if sz_w == 1920:
        skin = """
        <screen name="PWemulator" position="center,170" size="1200,350" title="PWemulator" >
    	<widget name="logo" position="20,10" size="150,60" />
	<widget backgroundColor="#9f1313" font="Regular;30" halign="center" name="buttonred" position="190,10" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="240,60" valign="center" />
	<widget backgroundColor="#1f771f" font="Regular;30" halign="center" name="buttongreen" position="440,10" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="240,60" valign="center" />
	<widget backgroundColor="#a08500" font="Regular;30" halign="center" name="buttonyellow" position="690,10" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="240,60" valign="center" />
	<widget backgroundColor="#18188b" font="Regular;30" halign="center" name="buttonblue" position="940,10" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="240,60" valign="center" />
	<eLabel backgroundColor="grey" position="20,80" size="1160,1" />
        <widget enableWrapAround="1" name="config" position="10,90" scrollbarMode="showOnDemand" size="1180,230" />
    	</screen>"""
    else:
        skin = """
        <screen name="PWemulator" position="center,120" size="800,220" title="PWemulator" >
	<widget name="logo" position="10,5" size="100,40" />
	<widget backgroundColor="#9f1313" font="Regular;19" halign="center" name="buttonred" position="120,5" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="160,40" valign="center" />
	<widget backgroundColor="#1f771f" font="Regular;19" halign="center" name="buttongreen" position="290,5" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="160,40" valign="center" />
	<widget backgroundColor="#a08500" font="Regular;19" halign="center" name="buttonyellow" position="460,5" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="160,40" valign="center" />
	<widget backgroundColor="#18188b" font="Regular;19" halign="center" name="buttonblue" position="630,5" foregroundColor="white" shadowColor="black" shadowOffset="-2,-2" size="160,40" valign="center" />
	<eLabel backgroundColor="grey" position="10,50" size="780,1" />
        <widget name="config" position="10,60" size="780,150" enableWrapAround="1" scrollbarMode="showOnDemand" />
    	</screen>"""

    def __init__(self, session, args = 0):
	Screen.__init__(self, session)

        self.onShown.append(self.setWindowTitle)

	self.onChangedEntry = []  
        self.list = []
       	ConfigListScreen.__init__(self, self.list, session = self.session, on_change = self.changedEntry)
       	self.createSetup()

	self["logo"] = Pixmap()
       	self["buttonred"] = Label(_("Exit"))
       	self["buttongreen"] = Label(_("OK"))
       	self["buttonyellow"] = Label(_(" "))
	self["buttonblue"] = Label(_("About"))
        self["setupActions"] = ActionMap(["SetupActions", "ColorActions"],
       	{
       		"green": self.save,
        	"red": self.cancel,
	       	"yellow": self.cancel,
        	"blue": self.about,
            	"save": self.save,
            	"cancel": self.cancel,
            	"ok": self.save,
       	})

    def createSetup(self):
       	self.list = []
	self.list.append(getConfigListEntry(_("max rmp"), config.plugins.pwe.maxrpm))
      	self.list.append(getConfigListEntry(_("min rpm"), config.plugins.pwe.minrpm))
	self.list.append(getConfigListEntry(_("max Temperature"), config.plugins.pwe.maxtemp))
      	self.list.append(getConfigListEntry(_("min Temperature"), config.plugins.pwe.mintemp))
      	self.list.append(getConfigListEntry(_("Idle"), config.plugins.pwe.idle))
       	self["config"].list = self.list
        self["config"].l.setList(self.list)

    def setWindowTitle(self):
	if os.path.exists("%s/pwe.png" % pwe_plugindir):
		self["logo"].instance.setPixmapFromFile("%s/pwe.png" % pwe_plugindir)
	self.setTitle("PWM Emulator"+" V%s " % pwe_version)

    def changedEntry(self):         
        choice = self["config"].getCurrent()                                    
        current=choice[1]                
        if choice != None:        
        	self.createSetup()

    def save(self):
        for x in self["config"].list:
           x[1].save()
	config.plugins.pwe.maxtemp.save()
	if (int(config.plugins.pwe.mintemp.value)+2) > int(config.plugins.pwe.maxtemp.value):
		print "[PWemulator] mintemp has to be at least 2 degrees lower than maxtemp"
		config.plugins.pwe.mintemp.value=int(config.plugins.pwe.maxtemp.value)-2
	config.plugins.pwe.mintemp.save()
	config.plugins.pwe.idle.save()
	if os.path.exists("/proc/stb/fp/fan_speed_max"):
		f=open("/proc/stb/fp/fan_speed_max","w")
		f.write("%s rpm\n" % config.plugins.pwe.maxrpm.value)
		f.close()
	if os.path.exists("/proc/stb/fp/fan_speed_min"):
		f=open("/proc/stb/fp/fan_speed_min","w")
		f.write("%s rpm\n" % config.plugins.pwe.minrpm.value)
		f.close()
        self.close(True)

    def cancel(self):
        for x in self["config"].list:
           x[1].cancel()
        self.close(False)

    def about(self):
	message=_("PWM Emulator")+" "+_("Plugin")+" (c) gutemine 2018" 
	self.session.open(MessageBox, message, MessageBox.TYPE_INFO)

def autostart(reason,**kwargs):
        if kwargs.has_key("session") and reason == 0:
		session = kwargs["session"]
		print "[PWemulator] autostart"

def main(session,**kwargs):
     session.open(PWemulator)

def Plugins(**kwargs):
	return [PluginDescriptor(name=_("PWemulator"), description="PWM Emulation", where = PluginDescriptor.WHERE_MENU, fnc=mainconf),
		PluginDescriptor(where = [PluginDescriptor.WHERE_SESSIONSTART, PluginDescriptor.WHERE_AUTOSTART], fnc = autostart)]

def mainconf(menuid):
    print "[PWemulator] menu:", menuid
    if menuid == "system":
	return [("PWM Emulator", main, "pwemulator", None)]
    else:
	return [ ]

